pub struct AssertError { /* private fields */ }Expand description
Assert error (see AssertResult).
Implementations
Sourceimpl AssertError
impl AssertError
Sourcepub fn assert(self) -> Assert
pub fn assert(self) -> Assert
Returns the Assert wrapped into the Result produced by
the try_ variants of the Assert methods.
Examples
use assert_cmd::prelude::*;
use std::process::Command;
use predicates::prelude::*;
let result = Command::new("echo")
.assert();
match result.try_success() {
Ok(assert) => {
assert.stdout(predicate::eq(b"Success\n" as &[u8]));
}
Err(err) => {
err.assert().stdout(predicate::eq(b"Err but some specific output you might want to check\n" as &[u8]));
}
}Trait Implementations
Sourceimpl Debug for AssertError
impl Debug for AssertError
Sourceimpl Display for AssertError
impl Display for AssertError
Sourceimpl Error for AssertError
impl Error for AssertError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()