cargo_bin_cmd

Macro cargo_bin_cmd 

macro_rules! cargo_bin_cmd {
    () => { ... };
    ($bin_target_name:expr) => { ... };
}
A Command for the binary target’s executable.

The bin_target_name is the name of the binary target, exactly as-is.

NOTE: This is only set when building an integration test or benchmark.

Example

use assert_cmd::prelude::*;
use assert_cmd::cargo::cargo_bin_cmd;

use std::process::Command;

let mut cmd = cargo_bin_cmd!();
let output = cmd.unwrap();